@@ -17,7 +17,7 @@ def convert_time_str_to_datetime(time_str_series):
         converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f") if (type(x) == str) else x
     else:
         converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S") if (type(x) == str) else x
-    time_datetime_list = [x.split(" ")[0] + " " + x.split(" ")[1] if type(x) == str else x for x in
+    time_datetime_list = [x.split(" ")[0] + " " + x.split(" ")[1] if (type(x) == str) or (len(x.split(" ")) < 2) else x for x in
                           list(time_str_series)]
 
     time_datetime_list = pd.Series(map(converter, time_datetime_list))
